use tracing::Level;
use tracing_subscriber::FmtSubscriber;

use wrbapp_server::database;

#[tokio::main]
async fn main() {
    dotenvy::dotenv().ok();

    // Initialize logging
    let subscriber = FmtSubscriber::builder()
        .with_max_level(Level::INFO)
        .finish();

    tracing::subscriber::set_global_default(subscriber)
        .expect("Error while initialized tracing subscriber");

    // Initialize database connection
    database::apply_migrations()
        .await
        .expect("Database migrations failed");

    let pool = database::connect()
        .await
        .expect("Database connection failed");

    wrbapp_server::util::cli::parse(pool).await;
}
